Experiment

Enum Experiment 

pub enum Experiment {
    ResetRetryOnAckUpdate,
    ResendOnRrCommand,
}
A set of experiments to enable on the implementation outside of the official spec.

Variants



ResetRetryOnAckUpdate

Normally, when an iframe arrives with a new ACK value, that will register the ACK just fine and deliver the data. But it doesn’t cause the retry counter to reset.

So even though both peers may be getting data through and make progress, they may both “give up” and end the connection with a DM.

That kind of makes sense, in that an RR response means “I heard you”. But so does an iframe with a new sequence number.

https://github.com/packethacking/ax25spec/issues/9



ResendOnRrCommand

Normally, we only retransmit if we get an RR response. But if we are waiting for an RR response, and we get an RR command, why not issue the retransmit right now.

https://github.com/packethacking/ax25spec/issues/8