Data

Struct Data 

pub struct Data { /* private fields */ }
Connection (or socket, if you will) extra data.

The state object only carries the state itself. Further data is in this object.

Implementations

Source

impl Data

pub fn new(me: Addr) -> Self

Create new Data with the specified address being the local one.

pub fn srt_default(&mut self, v: Duration)

Set default T1 timer / smoothed roundtrip.

pub fn t3v(&mut self, v: Duration)

Set T3 / idle timer.

pub fn enable_experiment(&mut self, ex: Experiment)

Enable an experiment.

pub fn mtu(&mut self, v: usize)

Set MTU.

pub fn ext(&self) -> bool

Return true if using 128 modulus.

pub fn t1_expired(&self) -> bool

Return true if T1 (retry) has expired.

pub fn t3_expired(&self) -> bool

Return true if T3 (idle timer) has expired.

pub fn active_timers(&self) -> Vec<Event>

Return list of expired timers.

pub fn next_timer_remaining(&self) -> Option<Duration>

Return time until next timer expires, or None if no timer is currently running.